tabbed_view
library
Typedefs
-
CanDrop
= bool Function(DraggableData source, TabbedViewController target)
-
-
IconPath
= Path Function(Size size)
-
Builds a responsive path given a size. Used to draw a icon.
-
OnBeforeDropAccept
= bool Function(DraggableData source, TabbedViewController target, int newIndex)
-
-
OnDraggableBuild
= DraggableConfig Function(TabbedViewController controller, int tabIndex, TabData tab)
-
Defines the configuration of a Draggable in its construction.
-
OnReorder
= void Function(int oldIndex, int newIndex)
-
Event that will be triggered when the tab is reorder.
-
OnTabClose
= void Function(int tabIndex, TabData tabData)
-
The event that will be triggered after the tab close.
-
OnTabSelection
= dynamic Function(int? newTabIndex)
-
Event that will be triggered when the tab selection is changed.
-
Menu builder
-
TabCloseInterceptor
= FutureOr<bool> Function(int tabIndex, TabData tabData)
-
Intercepts a close event to indicates whether the tab can be closed.
-
TabLeadingBuilder
= Widget? Function(BuildContext context, TabStatus status)
-
Signature for a function that builds a leading widget in tab.
-
TabsAreaButtonsBuilder
= List<TabButton> Function(BuildContext context, int tabsCount)
-
Tabs area buttons builder
-
TabSelectInterceptor
= bool Function(int newTabIndex)
-
Intercepts a select event to indicate whether the tab can be selected.